July 26, 2020

Package contains-
Binomialdistributions.py
Gaussiandistributions.py
Generaldistributions.py

This modularized code is used for computing binomial and gaussian distributions

Gaussian and Binomial are classes that inherit the class Distributions

In application, provide the mean and standard deviation for Gaussian and; provide the probability and sample size for Binomial

Refer to the comments in the package files for further detail

